# Imba Contributing Guide 1.0

> First off, thank you for considering making a contribution to [Imba](https://github.com/somebee/imba). 
People like you inspire our commitment to open-source.

The goal of this document is to create a contribution process that:

* Encourages new contributions.
* Encourages contributors to remain involved.
* Creates a transparent decision making process that makes it clear how contributors can be involved in decision making.

## Vocabulary

* A **Contributor** is any individual creating or commenting on an issue or pull request.
* A **Committer** is a subset of contributors who have been given write access to the repository.

# Logging Issues

Log an issue for any question, feature, enhancement or problem you might have [here](https://github.com/somebee/imba/issues), while adding any additional policies about what to include in the responses. The only exception is security dislosures which should be sent privately.

In most cases where there is a bug, Committers may direct you to another repository, ask for additional clarifications, and
add appropriate metadata before the issue is addressed.

Please be courteous and respectful. Every participant is expected to follow the project's Code of Conduct.

Keep an open mind! Improving documentation, bug triaging, or writing tutorials are all examples of helpful contributions that 
mean less work for you.

# Contributions

### Ground Rules

> Responsibilities
> * Ensure cross-platform compatibility for every change that's accepted. Windows, Mac, Debian & Ubuntu Linux.
> * Ensure that code that goes into core meets all requirements and pass tests. 
> * Create issues for any major changes and enhancements that you wish to make. Discuss things transparently and try to get [community](https://github.com/somebee/imba/issues) feedback.
> * Keep feature versions as small as possible, preferably one new feature per version.
> * Be welcoming to newcomers and encourage diverse new contributors from all backgrounds. Check our [CODE OF
CONDUCT](CODE_OF_CONDUCT.md)




Any change to resources in this repository must be through pull requests. This applies to all changes
to documentation, code, binary files, etc. Even long term committers and Project Maintainers must use
pull requests.

No pull request can be merged without being reviewed.

For non-trivial contributions, pull requests should sit for at least 36 hours to ensure that
contributors in other timezones have time to review. Consideration should also be given to
weekends and other holiday periods to ensure active committers all have reasonable time to
become involved in the discussion and review process if they wish.

The default for each contribution is that it is accepted once no committer has an objection.
During review committers may also request that a specific contributor who is most versed in a
particular area gives a "LGTM" before the PR can be merged. There is no additional "sign off"
process for contributions to land. Once all issues brought by committers are addressed it can
be landed by any committer.

In the case of an objection being raised in a pull request by another committer, all involved
committers should seek to arrive at a consensus by way of addressing concerns being expressed
by discussion, compromise on the proposed change, or withdrawal of the proposed change.

If a contribution is controversial and committers cannot agree about how to get it to land
or if it should land then it should be escalated to any of the Project Maintainers, 
[@somebee](https://github.com/somebee/) .

Project Maintainers should regularly discuss pending contributions in order to find a resolution. It is expected that only a
small minority of issues be brought to the Project Maintainers for resolution and that discussion and compromise among 
committers be the default resolution mechanism.
